@@ -1,10 +1,39 @@
 import abc
 import itertools
+from dataclasses import dataclass
 from functools import reduce
 from typing import Any, Callable, List, Literal, Mapping, Union
 
+from .utility import compress
+
 TaggedDocument = Mapping[str, List[str]]
-IterateLevel = Literal['protocol', 'speech', 'speaker', 'utterance', 'paragraph']
+IterateLevel = Literal['protocol', 'speech', 'speaker', 'who', 'utterance', 'paragraph']
+
+
+@dataclass
+class ProtocolIterItem:
+
+    name: str
+    who: str
+    id: str
+    text: str
+    page_number: str
+
+    def __repr__(self) -> str:
+
+        # text2 = zlib.decompress(base64.b64decode(text_base64)).decode('utf-8')
+
+        return (
+            f"{self.name or '*'}\t"
+            f"{self.id or '?'}\t"
+            f"{self.who or '*'}\t"
+            f"{self.page_number or ''}\t"
+            f"{len(self.text)/1024.0:.2f}kB\t"
+        )
+
+    def text_z64(self) -> bytes:
+        """Compress text, return base64 encoded string."""
+        return compress(self.text)
 
 
 class IProtocol(abc.ABC):
